'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = parse;
exports.phone_number_digits = phone_number_digits;

var _phone = require('../phone');

function parse(text, caret_position, format) {
	var options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

	// Extract phone number digits (they may be altered later on).
	var digits = phone_number_digits(text, format, options);

	// Current digit index in the phone number
	// (not a character index, but a digit index)
	var digit_index = (0, _phone.digit_index)(text, caret_position);

	// In case `format` is specified, excessive
	// phone number digits may have been cut off,
	// so check that and adjust `digit_index` accordingly.
	if (digit_index > digits.length) {
		digit_index = digits.length;
	}

	return { digits: digits, digit_index: digit_index };
}

// Extracts phone number digits,
// cutting off excess digits.
// 
// If no specific `format` is required,
// and instead the most suitable
// phone number `format` is selected dynamically,
// then don't pass the `format` arguments,
// and it won't cut off the excessive digits,
// allowing for further dynamic phone number format selection.
//
function phone_number_digits(text, format) {
	var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

	if (format) {
		return (0, _phone.local_phone_digits)(text, format, options.has_trunk_prefix);
	}

	return (0, _phone.parse_digits)(text);
}
//# sourceMappingURL=parser.js.map